/*
  Melody
 
 Plays a melody 
 
 circuit:
 * 8-ohm speaker on digital pin 8
 
 created 21 Jan 2010
 modified 30 Aug 2011
 by Tom Igoe 

This example code is in the public domain.
 
 http://arduino.cc/en/Tutorial/Tone
 
 */
 #include "pitches.h"

const int bledPin = 12; // the pin that the LED is attached to
const int rledPin = 13; // the pin that the LED is attached to
int incomingByte;      // a variable to read incoming serial data into

// notes in the melody:
int melody[2][49] = {{NOTE_C4, NOTE_G3, NOTE_G3, NOTE_A3, NOTE_G3, 0, NOTE_B3, 
                      NOTE_C4, 0, 0, 0, 0, 0, 0, 
                      0, 0, 0, 0, 0, 0, 0,
                      0, 0, 0, 0, 0, 0, 0,
                      0, 0, 0, 0, 0, 0, 0,
                      0, 0, 0, 0, 0, 0, 0,
                      0, 0, 0, 0, 0, 0, 0 },
                    {NOTE_C2, NOTE_C3, NOTE_C4, NOTE_C5, NOTE_CS2, NOTE_CS3, NOTE_CS4, 
                     NOTE_CS5, NOTE_D2, NOTE_D3, NOTE_D4, NOTE_D5, NOTE_DS2, NOTE_DS3,
                     NOTE_DS4, NOTE_DS5, NOTE_E2, NOTE_E3, NOTE_E4, NOTE_E5, NOTE_F2,
                     NOTE_F3, NOTE_F4, NOTE_F5, NOTE_FS2, NOTE_FS3, NOTE_FS4, NOTE_FS5,
                     NOTE_G2, NOTE_G3, NOTE_G4, NOTE_G5, NOTE_GS2, NOTE_GS3, NOTE_GS4, 
                     NOTE_GS5, NOTE_A2, NOTE_A3, NOTE_A4, NOTE_A5, NOTE_AS2, NOTE_AS3,
                     NOTE_AS4, NOTE_AS5, NOTE_B2, NOTE_B3, NOTE_B4, NOTE_B5, NOTE_C6 }};
                     
const int sizeMelody = 49;

// note durations: 4 = quarter note, 8 = eighth note, etc.:
int noteDurations[49] = {
  4, 8, 8, 4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4 };

void setup() {
  // initialize serial communication:
  Serial.begin(9600);
  // initialize the LED pin as an output:
  pinMode(rledPin, OUTPUT);
  // initialize the LED pin as an output:
  pinMode(bledPin, OUTPUT);
  play(0);
}

void loop() {  
  // see if there's incoming serial data:
  if (Serial.available() > 0) {
    // read the oldest byte in the serial buffer:
    incomingByte = Serial.read();
    //Serial.print(incomingByte);
    // if it's a capital H (ASCII 72), turn on the LED:
    if (incomingByte == 'O') {
      digitalWrite(rledPin, LOW);
      digitalWrite(bledPin, HIGH);
      play(0);
      delay(2000);
    } 
    else if (incomingByte == 'I') {
      digitalWrite(bledPin, LOW);
      digitalWrite(rledPin, HIGH);
      play(1);
      delay(2000);
    } 
    //digitalWrite(ledPin, LOW);
  }
}

void play(int index) {
  // iterate over the notes of the melody:
  for (int thisNote = 0; thisNote < sizeMelody; thisNote++) {

    // to calculate the note duration, take one second 
    // divided by the note type.
    //e.g. quarter note = 1000 / 4, eighth note = 1000/8, etc.
    int noteDuration = 1000/noteDurations[thisNote];
    tone(8, melody[index][thisNote],noteDuration);

    // to distinguish the notes, set a minimum time between them.
    // the note's duration + 30% seems to work well:
    int pauseBetweenNotes = noteDuration * 1.30;
    delay(pauseBetweenNotes);
    // stop the tone playing:
    noTone(8);
  }
}

